@@ -45,7 +45,7 @@ class Domoticz(IPlugin):
 		log.msg("index :  %s" % (idex)		
 		for rs in self.configuration_plugin['param_dz']
 			if rs['ids'] == idex
-				bod = rs(boy)
+				bod = rs['boy']
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs[idx],on_off.capitalize()))
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
